#encoding=utf-8

import os
import time
import requests
import json

URL = "http://www.bangnikanzhe.com/wx/sendstockmsg"
# URL = "http://127.0.0.1/wx/sendstockmsg"
userName=""
userPwd=""
 
def init(name, pwd):
    global userName
    global userPwd
    userName = name
    userPwd = pwd
    pass

def sendMsg(txt1,txt2,txt3):
    if userName == "":
        return '{"code": "9999","msg": "not init user name, call Init(name, pwd)"}'
    data = makeData(userName,userPwd,txt1,txt2,txt3)
    return postJson(data)


def sendMsgToUser(name,pwd,txt1,txt2,txt3):
    data = makeData(name,pwd,txt1,txt2,txt3)
    return postJson(data)

def postJson( data ):
    headers = {"Content-Type":"application/json"}
    try:
        jsdata = json.dumps( data )
        r=requests.post(URL,data=jsdata,headers=headers,timeout=3)
        # print r.text   
        return r.text    
    except Exception, e:
        print(e)
        return '{"code": "9999","msg": "http post error"}'
    pass

def makeData(name,pwd, txt1,txt2,txt3):
    msg = {"userid": name, "mark": "", "kw1": "kw1", "kw3": txt3, "kw2": txt2, "userpwd":  pwd,
        "first": txt1 }    
    return msg

# name = "80010120"
# pwd ="88888"
# txt1 ="a"
# txt2 ="b"
# txt3 ="c"
# result = sendMsgToUser(name, pwd,txt1,txt2,txt3)

# init(name, pwd)
# result = sendMsg(txt1,txt2,txt3)
# print(result) 




#!/usr/bin/env python

import re
import setuptools

version = "1.0.2"
long_description ="this package is  send wx message to your phone "
# with open('wxmpy/__init__.py', 'r') as fd:
#     version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
#                         fd.read(), re.MULTILINE).group(1)

# with open("README.md", "r") as fh:
#     long_description = fh.read()

setuptools.setup(
    name="wxmpy",
    version=version,
    author="rehylas",
    author_email="rehylas@sina.com",
    description="send wx message  to my phone.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://github.com/rehylas/wxmpy",
    install_requires=[
        # 'requests!=2.9.0',
    ],
    packages=setuptools.find_packages(exclude=("test")),
    classifiers=(
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5"
    ),
    exclude_package_data={'': ["wxmpy/test.py", "wxmpy/config.txt"]},
)